=========
Changelog
=========

Unreleased
==========

-

Version 0.4
===========

- update on plots of datasets with irregular grids
- Quick inspection table added
- IQC instead of StdDev added to plots

Version 0.3.4
=============

- Switch from Travis CI to GitHub Actions
- Allow plotting from irregular grids (SMOS, ASCAT)

Version 0.3.3
=============

- Fix bug that lead to failing plots for CCI combined

Version 0.3.2
=============

- Fix bug that could break global overview maps
- Resolve deprecation warnings caused by cartopy

Version 0.3.1
=============

- Change how plots are named
 
Version 0.3
===========

- Fixes for integration in QA4SM Prod

Version 0.2
===========

- Updates for TC, refactoring

Version 0.1
===========

- First implementation


